@@ -5,6 +5,7 @@ from rich.logging import RichHandler
 
 from .enumerate import app as enum_app
 from .streams import app as sub_app
+from .fact import app as fac_app
 
 
 console = Console()
@@ -26,6 +27,7 @@ def main(verbose: bool = False):
 
 app.add_typer(enum_app, name="enumerate")
 app.add_typer(sub_app, name="streams")
+app.add_typer(fac_app, name="fact")
 
 
 typer_click_object = typer.main.get_command(app)
