@@ -1,4 +1,4 @@
-from typing import Iterable
+from typing import Iterable, List
 from uuid import UUID
 import typer
 from rich.console import Console
@@ -17,7 +17,13 @@ def print_iterable_as_json_list(
 ) -> None:
     console.print("[")
     it = iter(iterable)
-    last = next(it)  # type: ignore
+
+    try:
+        last = next(it)  # type: ignore
+    except StopIteration:
+        console.print("]")
+        return
+
     for elem in it:
         console.print(f"{last.json(indent=2)},", soft_wrap=True)
         last = elem
@@ -38,9 +44,18 @@ def subscribe(
         None, help="Get all events in the stream that happened after a certain ID."
     ),
     json_format: bool = typer.Option(False, "--json", help="Output raw json events."),
+    fact_types: List[str] = typer.Option(
+        [],
+        "--type",
+        help="The types of events to get. Can be used multiple times. Supports regexp.",
+    ),
 ) -> None:
     subscription = business.subscribe(
-        namespace=namespace, follow=follow, after_fact=after_fact, from_now=from_now
+        namespace=namespace,
+        follow=follow,
+        after_fact=after_fact,
+        from_now=from_now,
+        fact_types=fact_types,
     )
     """
     Subscribe to an eventstream.
