@@ -3,7 +3,7 @@ from __future__ import annotations
 from typing import Type, TypeVar, Dict, List, Optional
 
 from pyfactcast.grpc.generated.FactStore_pb2 import MSG_Notification
-from pydantic import BaseModel, Json, Extra, constr
+from pydantic import BaseModel, Extra, constr
 
 import json
 
@@ -27,17 +27,19 @@ class FactHeader(BaseModel):
     class Config:
         extra = Extra.allow
 
+    ns: str
+    type: str
     id: Id  # type: ignore
     aggIds: Optional[List[AggsId]] = None  # type: ignore
-    ns: str
-    type: Optional[str] = None
-    meta: Optional[Dict[str, str]] = None
+    meta: Dict[str, str] = {}
 
 
 class Fact(BaseModel):
     header: FactHeader
-    payload: Json
+    payload: Dict
 
     @classmethod
     def from_msg(cls: Type[F], msg: MSG_Notification) -> F:
-        return cls(header=json.loads(msg.fact.header), payload=msg.fact.payload)
+        return cls(
+            header=json.loads(msg.fact.header), payload=json.loads(msg.fact.payload)
+        )
