@@ -1,3 +1,4 @@
+import json
 import logging
 import grpc
 import struct
@@ -9,6 +10,8 @@ from uuid import UUID
 from pyfactcast.grpc.generated.FactStore_pb2_grpc import RemoteFactStoreStub
 from pyfactcast.grpc.generated.FactStore_pb2 import (
     MSG_Empty,
+    MSG_Fact,
+    MSG_Facts,
     MSG_String,
     MSG_SubscriptionRequest,
     MSG_Notification,
@@ -34,6 +37,9 @@ def get_synchronous_grpc_client(
     if not client_configuration:
         client_configuration = get_client_configuration()
 
+    if client_configuration.insecure:
+        return RemoteFactStoreStub(grpc.insecure_channel(client_configuration.server))
+
     options = None
     if client_configuration.ssl_target_override:
         options = (
@@ -136,10 +142,15 @@ class FactStore:
         continuous: bool = False,
         from_now: bool = False,
         after_fact: UUID = None,
+        fact_types: Iterable[str] = [],
     ) -> Iterable[Fact]:
 
+        specs = [{"ns": namespace}]
+        if fact_types:
+            specs = [{"ns": namespace, "type": fact_type} for fact_type in fact_types]
+
         subscription_request_body = {
-            "specs": [{"ns": namespace}],
+            "specs": specs,
             "continuous": continuous,
         }
 
@@ -165,3 +176,13 @@ class FactStore:
         if res.present:
             return str(res.serial)
         return None
+
+    def publish(self, *, fact: Fact, conditional: bool = False) -> None:
+        if conditional:
+            raise NotImplementedError()
+        else:
+            fact_msg = MSG_Fact(
+                header=fact.header.json(), payload=json.dumps(fact.payload)
+            )
+            msg = MSG_Facts(fact=[fact_msg])
+            self.client.publish(msg)
